@@ -2,6 +2,7 @@ package HTML::FormHandler::Fields;
 # ABSTRACT: internal role for form and compound fields
 
 use Moose::Role;
+use HTML::FormHandler::TraitFor::Types;
 
 
 has 'fields' => (
@@ -35,10 +36,11 @@ sub add_error_field {
 sub num_error_fields { shift->result->num_error_results }
 
 has 'field_name_space' => (
-    isa     => 'Str|ArrayRef[Str]|Undef',
+    isa     => 'HFH::ArrayRefStr',
     is      => 'rw',
     lazy    => 1,
     default => '',
+    coerce  => 1,
 );
 
 sub field_index {
@@ -198,7 +200,7 @@ HTML::FormHandler::Fields - internal role for form and compound fields
 
 =head1 VERSION
 
-version 0.35003
+version 0.35004
 
 =head1 SYNOPSIS
 
