@@ -7,9 +7,9 @@ sub _add_html_attributes {
     my $self = shift;
 
     my $output = q{};
-    my $html_attr = $self->html_attr;
+    my $html_attr = { %{$self->html_attr} };
     for my $attr ( 'readonly', 'disabled', 'style', 'title', 'tabindex' ) {
-        $html_attr->{$attr} = $self->$attr if $self->$attr;
+        $html_attr->{$attr} = $self->$attr if !exists $html_attr->{$attr} && $self->$attr;
     }
     foreach my $attr ( sort keys %$html_attr ) {
         $output .= qq{ $attr="} . $html_attr->{$attr} . qq{"};
@@ -32,7 +32,7 @@ HTML::FormHandler::Widget::Field::Role::HTMLAttributes - apply HTML attributes
 
 =head1 VERSION
 
-version 0.35003
+version 0.35004
 
 =head1 AUTHOR
 
